function varargout = elemi_bif(varargin)
% ELEMI_BIF MATLAB code for elemi_bif.fig
%      ELEMI_BIF, by itself, creates a new ELEMI_BIF or raises the existing
%      singleton*.
%
%      H = ELEMI_BIF returns the handle to a new ELEMI_BIF or the handle to
%      the existing singleton*.
%
%      ELEMI_BIF('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in ELEMI_BIF.M with the given input arguments.
%
%      ELEMI_BIF('Property','Value',...) creates a new ELEMI_BIF or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before elemi_bif_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to elemi_bif_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help elemi_bif

% Last Modified by GUIDE v2.5 16-May-2011 10:12:17

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @elemi_bif_OpeningFcn, ...
                   'gui_OutputFcn',  @elemi_bif_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before elemi_bif is made visible.
function elemi_bif_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to elemi_bif (see VARARGIN)

% Choose default command line output for elemi_bif
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes elemi_bif wait for user response (see UIRESUME)
% uiwait(handles.figure1);
mu = get(handles.slider1, 'Value');
omega = get(handles.slider2, 'Value');
[t, phi] = ode45(@(t,x)elemi(t,x,mu,omega),[0 10],[1 1]);
plot(handles.axes1, phi(:,1),phi(:,2));
xlim(handles.axes1,[-5 5]);
ylim(handles.axes1,[0 1]);

% --- Outputs from this function are returned to the command line.
function varargout = elemi_bif_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on slider movement.
function slider1_Callback(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
mu = get(handles.slider1, 'Value');
omega = get(handles.slider2, 'Value');
set(handles.text1,'String',num2str(mu));
[t, phi] = ode45(@(t,x)elemi(t,x,mu,omega),[0 10],[1 1]);
plot(handles.axes1, phi(:,1),phi(:,2));
xlim(handles.axes1,[-5 5]);
ylim(handles.axes1,[0 1]);

% --- Executes during object creation, after setting all properties.
function slider1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function slider2_Callback(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
mu = get(handles.slider1, 'Value');
omega = get(handles.slider2, 'Value');
set(handles.text2,'String',num2str(omega));
[t, phi] = ode45(@(t,x)elemi(t,x,mu,omega),[0 10],[1 1]);
plot(handles.axes1, phi(:,1),phi(:,2));
xlim(handles.axes1,[-5 5]);
ylim(handles.axes1,[0 1]);

% --- Executes during object creation, after setting all properties.
function slider2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end
